#
# spec file for package subnetcalc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           subnetcalc
Version:        2.6.1
Release:        1.1
Summary:        IPv4/IPv6 Subnet Calculator
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Routing
URL:            https://www.nntb.no/~dreibh/subnetcalc/
Source:         https://github.com/dreibh/%{name}/archive/refs/tags/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++

%description
SubNetCalc is an IPv4/IPv6 subnet address calculator. For a given IPv4 or IPv6
address and netmask or prefix length, it calculates network address, broadcast
address, maximum number of hosts and host address range. It also prints the
addresses in binary format for better understandability. Furthermore, it
prints information on specific address types (e.g. type, scope,
interface ID, etc.).

%lang_package

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       bash-completion
Supplements:    (%{name} and bash)
BuildArch:      noarch

%description bash-completion
The bash completion script for %{name}, generated during the build.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
Recommends:     %{name} = %{version}
BuildArch:      noarch

%description doc
SubNetCalc is an IPv4/IPv6 subnet address calculator.
This packages provides documentation and help files for subnetcalc.

%prep
%autosetup -n %{name}-%{name}-%{version}

%build
%cmake
%cmake_build

%install
%cmake_install

%find_lang %{name}

%check
%{buildroot}%{_bindir}/%{name} 192.168.1.0/255.255.0.0

%files
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion

%files lang -f %{name}.lang
%{_datadir}/locale/de/LC_MESSAGES/subnetcalc*
%{_datadir}/locale/nb/LC_MESSAGES/subnetcalc*

%files doc
%doc AUTHORS ChangeLog README.md

%changelog
* Sat Jan  4 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to 2.6.1:
  * Improved address type handling for special cases
  * Bugfix: Print correct hostname when nocolor mode is on
  * Added option to print program version
- added bash completion and translation packages
* Thu Feb 22 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 2.4.1:
  * Fix for output to stderr instead of stdout for 6to4 address
  * Update metadata and code clean-up
  * Format IPv4-embedded IPv6 addresses
  * Test script fix
* Tue Jan  9 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 2.4.23:
  * updates to LSM entry, build scripts, cleanup packaging and dependency improvements
* Mon Aug  7 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 2.4.22:
  * Bugfix: Fixed wrong handling of 7th block in solicited node multicast address
  * minor cleaup
* Tue Feb 21 2023 Andrea Manzini <andrea.manzini@suse.com>
- split documentation in a separate package
* Tue Feb 21 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 2.4.21:
  * project URL change from UDE to NNTB.
  * Updated build scripts
  * Updated README.md
* Mon Nov 15 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Dependency update.
  - Version update.
  - Updated build scripts
  - Updated LSM entry.
* Tue Nov  2 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to 2.4.18:
  - no upstream changelog available
* Sun Jun  7 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.4.16:
  * build script fixes, fixes for other platforms and minor fixes
* Sat Nov 16 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove dependency on deprecated GeoIP-devel, fixes boo#1156201
- update to version 2.4.14:
  - Removed FreeBSD dependency on GeoIP, since it is not available any more.
  - CMakeLists.txt for FreeBSD builds.
  - Removed obsolete helper scripts.
  - Updated CI scripts.
  - Updated build script.
  - Updated FreeBSD port files.
  - Improved Travis CI configuration.
  - Build script update.
  - Updated distinfo.
  - Updated LSM entry.
- update to version 2.4.13:
  - Fixed some inconsistencies in different packaging files.
  - Updated build scripts.
  - Simplified CMakeLists.txt.
  - Some clean-ups.
  - Build script updates.
  - Updated build script.
  - Updated CI scripts.
  - Updated Debian Standards version.
  - Updated Travis CI configuration.
  - Build script updates.
  - Updated FreeBSD ports files.
  - Updated LSM entry.
- update to version 2.4.12:
  - Bugfix: Fixed Bug #3 (https://github.com/dreibh/subnetcalc/issues/3).
  - Using Tar/XZ for archive.
  - CI script update.
  - Build script update.
  - Updated build scripts.
  - Improved build script.
  - An update.
- update to version 2.4.11:
  - Updated ChangeLog.
  - Updated Travis CI configuration.
  - Updated script.
  - A fix.
  - Updated build script.
  - A fix.
  - Improved CI scripts.
  - Improved CI scripts.
  - Updated RPM spec file.
  - Updated CI script.
  - Updated packaging files.
  - Improved CI script.
  - Updated CI scripts.
  - Build script updates.
  - Updated build scripts.
  - Updated build scripts.
  - Improved Travis CI configuration.
  - Build script fix.
  - Improved Travis CI configuration.
  - Minor update.
  - A fix.
  - Updated build scripts.
  - Minor clean-up.
  - Updated Travis CI configuration.
  - An update.
  - Updated Travis CI configuration.
  - Updated build scripts.
  - Build script updates.
  - Updated build scripts.
  - Build script update.
  - Improved build script.
  - Updated build scripts.
  - Updated build script.
  - Build script updates.
  - Added script.
  - Updated build scripts.
  - Another build script update.
  - Updated build scripts.
  - A fix.
  - Added missing file.
  - A fix.
  - Build script updates.
  - Header updates.
  - Dependency update.
  - Require CMake 3.0.2, to avoid inconsistent CMake behaviour in old versions.
  - Another try.
  - Setting language in CMakeLists.txt.
  - Updated build scripts.
  - Improved build scripts.
  - Merge branch 'dreibh/travis-ci'
  - A fix.
  - A fix.
  - Merge branch 'master' into dreibh/travis-ci
  - Update.
  - Updated packaging files.
  - Build script updates.
  - Improved CMakeLists.txt.
  - Updated FreeBSD packaging files.
  - Updated ChangeLog.
- update to version 2.4.10:
  - Updated LSM entry.
  - Updated FreeBSD packaging files.
  - Added tests control file.
  - Added metadata file.
  - Packaging script updates.
  - More clean-ups for CMakeLists.txt.
  - Cleaned up CMakeLists.txt.
  - RPM packaging fix.
  - An update.
  - Updated script.
  - Added Travis CI configuration.
  - Removed obsolete automake file.
  - Updated LSM entry.
  - Added configuration file.
- update to version 2.4.9:
  - Fixed compile options to allow building for Ubuntu Precise.
  - Updated build scripts.
  - Updated packaging files.
  - Build script updates.
  - Fedora build updates.
  - Updated standards version.
  - Build script updates.
  - Minor update.
  - Some updates.
  - Changed build system from autoconf/automake to cmake.
  - Improved build script.
  - Updated build scripts.
  - Updated FreeBSD port.
  - Updated script.
  - Updated FreeBSD port.
  - Script update.
  - Added helper script.
  - FreeBSD port update.
  - New release.
- update to version 2.4.8:
  - Removed old SVN Id tag, since it is obsolete after transition to Git.
  - Header updates.
  - Script update.
  - Fixed dependency.
- update to version 2.4.7 and 2.4.6:
  - Fixed URL.
  - Script update.
- update to version 2.4.5:
  - A fix.
  - Updated ChangeLog.
  - Updated packaging files.
  - A small fix.
  - Updated build scripts.
- update to version 2.4.4:
  - Updated LSM entry.
* Wed Jun 28 2017 jengelh@inai.de
- Whitespace/grammar fixes
* Mon Jun 19 2017 sebix+novell.com@sebix.at
- initial package
